'Driver for Rayman's mono LCD (120x32) graphical
' Notes:
'  Text is 0..19 x 0..3, Plotting is (0..119) x (0..31)
'
'  There are 4 static icons on the top left (Light bulb, Antenna, Speaker, Speaker slash). These are controlled
'    by using the SetIcons commands with a value from 0 to 15.
'
'  The rest of the icons on the top line are controlled by plotting or unplotting on line 32.
'    Only these positions are used: 0,16,17..23,25..31,33..39,41..47,52, 60,68,73..79,81..87,88,89..95,97..103,107,115,119  
'
'  Routines:
'    ClearScreen     - Clears screen. Does NOT clear icons
'    ClearIcons      - Clear static and non-static icons
'    SetIcons(value) - Controls the 4 static icons.value=0..15
'    Pos(x, y)       - Sets text position. x=0..19, y=0..3
'    PutChar(char)   - Displays 1 character.
'    PutStr(string)  - Displays a string of characters.  
'    Plot(x, y)      - Plots pixel (or icon). x=0..119, y=0..32 (32 is for icons)
'    UnPlot(x, y)    - Unplots pixel (or icon). x=0..119, y=0..32 (32 is for icons)
'
'  Note that the SendCommand, and SendData routines will NOT work after the driver is started.   
'

CON

  _clkmode = xtal1 + pll16x
  _xinfreq =5_000_000


OBJ
  LCD: "MonoLCD"


CON
  ' Change these pin numbers if you connect the LCD to different pins.
  PinRESn= 0  ' /Reset
  PinDC  = 1  ' Data /Command
  PinRW  = 2  ' Read /Write (can be just wired high, we never read back from the display)
  PinCSn = 3  ' Clock (data is read on falling edge) 
  PinD0  = 4  ' data byte bits are reversed to make wiring look better!
  PinD7  = 11 ' Note:  Breakout board has D0..7 labels backwards!


PUB Main | x, y
  ' Read_nWrite pin just gets held low, this code never reads from the LCD
  dira[PinRW]~~
  outa[PinRW]~
  
  LCD.Init(PinRESn, PinDC, PinCSn, PinD0) 

   repeat y from 0 to 31
    repeat x from 0 to 119
      LCD.Plot(x, y)
      WaitCnt(cnt+ClkFreq/10000)
  WaitCnt(cnt+ClkFreq)

  repeat x from 0 to 119
    LCD.Plot(x, 32)  
  LCD.SetIcons(15) ' All static icons on
  WaitCnt(cnt+ClkFreq)
  
  repeat y from 0 to 31
    repeat x from 0 to 119
      LCD.UnPlot(x, y)
      WaitCnt(cnt+ClkFreq/10000)
  WaitCnt(cnt+ClkFreq)

  repeat x from 0 to 119
    LCD.UnPlot(x, 32)  
  LCD.SetIcons(0) ' All static icons on
  WaitCnt(cnt+ClkFreq)

  LCD.ClearScreen
  LCD.PutStr(STRING("12345678901234567890"))
  LCD.PutStr(STRING("12345678901234567890"))
  LCD.PutStr(STRING("12345678901234567890"))
  LCD.PutStr(STRING("12345678901234567890"))
  WaitCnt(cnt+ClkFreq)

  LCD.ClearScreen
  WaitCnt(cnt+clkFreq)
  
  LCD.PutStr(STRING("Mono LCD by Rayman",13,"Available at:",13,"Gadget Gangster",13,"For Only $9.99"))
  
  repeat
  
  